Skip to contents

Get column dictionary for a specified table As an alternative to subsetting.

Usage

get_column_dict_for_table(
  table_name = "site_info",
  myurl = getOption("drivesR.default.url")
)

Arguments

table_name
myurl

Base url for the Directus database.

Value

A dataframe consisting of the subsetted column dictionary for the corresponding table.

Examples

#not run: cdict <- get_column_dict_for_table("site_info")