Skip to contents

Import dictionary tables These do not require an API key.

Usage

import_dictionary_tables()

Arguments

myurl

URL for the Directus database. Set as a default option (data.drives-network.org)

Value

A list of three dictionary tables. One describing database tables, one describing columns within tables, and one describing categories within columns.

Examples

# not run: dict <- import_dictionary_tables()