Skip to contents

Convert any unit per acre area to the same unit per hectare area

Usage

unitacre_to_unithectare(unitacre)

Arguments

unitacre

A value or numeric vectors in a per-acre unit, e.g., seeds/acre.

Value

A value or numeric vector in the equivalent per-hectare unit, e.g., seeds/ha