Check for mistakes in treatment components and years.
check_treatment_years.RdHarmonization steps require that: 1) Expanding by start and end years in experimental_unit_treatments results in a single row per treatment_id per unit_id per year (one for treatmentID1, one for treatmentID2) 2) Expanding by start and end years in treatment_id_components results in 1 level per treatment type and treatment id per year. 3) When these expanded tables are combined, there is only 1 level per treatment type, unit id, treatment id, and year.