Fetch schema information from directus
get_db_info.RdFetch schema information from directus
Arguments
- mytarget
The part of the URL indicating the part of the database you want schema information about. "collections" returns information about all tables. "collections/table_name" returns metadata on a specific collection.
For information about columns within a table, use "fields/table_name". For information about relations in a table, use "relations/table_name/column_name
- output_format
By default, the output is formatted as a data frame. There is also the option to format as a prettified json string.
- myurl
Base URL for the drives database.
- mytoken
User-specific Directus API token, in the format "Bearer myAPItoken" without curly brackets.
- flatten
If FALSE (default), the data dataframe will be nested. If TRUE, it will be flattened. Irrelevant if output is json.