Download content from an API fetch request into a data frame
get_table_from_req.RdThis is useful for api_request() that involves a json_body object, such as filtering for conditions in a table.
Examples
# not run:
# this example demonstrates how a query filter might be set up
# in an api request.
# querylist <-
# list("query"= list("filter" =
# list("table_name" =
# list("_eq" = "site_info")),
# "limit" = -1))
# queryjson <- toJSON(querylist, auto_unbox = TRUE)
# myreq <- api_request("SEARCH","items/column_dictionary", queryjson)
# outdf <- get_table_from_req(myreq)