Harmonize treatment components
harmonize_treatments.RdCombines information stored in the tables treatment_id_info and treatment_id_components into a time-series dataset describing combined experimental components for every year.
harmonize_treatments.RdCombines information stored in the tables treatment_id_info and treatment_id_components into a time-series dataset describing combined experimental components for every year.