Make a collection schema json object from data dictionary tables
make_collection_json.RdMake a collection schema json object from data dictionary tables
Usage
make_collection_json(
columndf = test_column_dict[which(test_column_dict$table_name == "test_cat_info"), ],
tablerow = test_table_dict[1, ]
)Examples
my_collection_json <-
make_collection_json(columndf =
test_column_dict[which(test_column_dict$table_name==
"test_cat_info"),],
test_table_dict[1,])