Get origin XY coordinates from longitude and latitude points. Used to estimate georeferenced plot geometry from map dimensions and points selected from Google Earth imagery.
originFromLonLat.RdGet origin XY coordinates from longitude and latitude points. Used to estimate georeferenced plot geometry from map dimensions and points selected from Google Earth imagery.
Usage
originFromLonLat(
lonlatvec,
lonlatcrs = 4326,
outcrs = "ESRI:102008",
outputtype = c("coordinates", "sf")[1]
)Arguments
- lonlatvec
A numeric vector of length 2 containing longitude followed by latitude in decimal degrees. Usually a point taken from Google Earth imagery.
- lonlatcrs
The Coordinate Reference System for the longitude latitude points. The default is WGS 84, ID EPSG 4326.
- outcrs
The Coordinate Reference System for the output coordinates. Usually this is a projection to meters. The default is ESRI:102008.
- outputtype
An option for whether the output should be a 1-row matrix of X Y coordinates (default) or an sf dataframe.