pg_to_directus_type.Rd
Map data types from Postgresql to Directus schema
pg_to_directus_type(pgtype)
A postgres data type as specified in the column dictionary
A character string with the corresponding datatype recognized by the Directus API.
pg_to_directus_type("array") #> [1] "text"