unitacre_to_unithectare.Rd
Convert any unit per acre area to the same unit per hectare area
unitacre_to_unithectare(unitacre)
A value or numeric vectors in a per-acre unit, e.g., seeds/acre.
A value or numeric vector in the equivalent per-hectare unit, e.g., seeds/ha